@@ -1,29 +1,20 @@
-from Acquisition import aq_parent, aq_inner
-
-from Products.CMFCore.utils import getToolByName
-
-from plone.z3cform.layout import wrap_form
-from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
-from zope.i18nmessageid import MessageFactory
-from z3c.form.interfaces import INPUT_MODE, DISPLAY_MODE
+from z3c.form.interfaces import INPUT_MODE
 from z3c.form import form as z3cform, field as z3cfield
 from z3c.form import button
-from z3c.form import field, group as z3cgroup
+from z3c.form import group as z3cgroup
 from z3c.formwidget.query.widget import QuerySourceFieldRadioWidget
 from z3c.form.browser.orderedselect import OrderedSelectWidget
-from z3c.form.widget import SequenceWidget, FieldWidget
+from z3c.form.widget import FieldWidget
 from z3c.form.browser import widget
-from plone.z3cform.fieldsets import group, extensible
-from zope.component import adapts, provideAdapter
-from zope.publisher.interfaces.browser import IBrowserRequest
-from zope.publisher.interfaces.http import IHTTPRequest
 
-from Solgema.fullcalendar.vocabularies import TitledVocabulary
+from Products.CMFCore.utils import getToolByName
+from Products.CMFPlone import PloneMessageFactory as plMF
+from plone.z3cform.layout import wrap_form
+from plone.z3cform.fieldsets import extensible
+
 from Solgema.fullcalendar.interfaces import ISolgemaFullcalendarProperties
-from Solgema.fullcalendar.widgets.widgets import ColorDictInputFieldWidget
-from Solgema.fullcalendar.content import SolgemaFullcalendarAdapter
 from Solgema.fullcalendar.config import _
-PLMF = MessageFactory('plone')
+
 
 class CriteriasOrderedSelectWidget(OrderedSelectWidget):
 
@@ -44,7 +35,6 @@ def CriteriasOrderedSelectFieldWidget(field, request):
     """IFieldWidget factory for SelectWidget."""
     return FieldWidget(field, CriteriasOrderedSelectWidget(request))
 
-
 class CalendarGroup(z3cgroup.Group):
     label = _(u'Calendar', default="Calendar")
 
@@ -52,6 +42,8 @@ class CalendarGroup(z3cgroup.Group):
         'slotMinutes',
         'allDaySlot',
         'defaultCalendarView',
+        'shortDayNameFormat',
+        'headerLeft',
         'headerRight',
         'weekends',
         'firstDay',
@@ -59,12 +51,17 @@ class CalendarGroup(z3cgroup.Group):
         'firstHour',
         'minTime',
         'maxTime',
+        'gcalSources',
         'target_folder',
         'calendarHeight',
-        'displayNoscriptList')
+        'displayNoscriptList',
+        'disableAJAX',
+        'caleditable',
+        'disableDragging',
+        'disableResizing')
     fields['target_folder'].widgetFactory[INPUT_MODE] = QuerySourceFieldRadioWidget
 
-class QueryGroup(z3cgroup.Group):
+class TopicQueryGroup(z3cgroup.Group):
     label = _(u'Query', default="Query")
 
     fields = z3cfield.Fields( ISolgemaFullcalendarProperties ).select(
@@ -73,25 +70,23 @@ class QueryGroup(z3cgroup.Group):
         'overrideStateForAdmin')
     fields['availableCriterias'].widgetFactory[INPUT_MODE] = CriteriasOrderedSelectFieldWidget
 
+class FolderQueryGroup(z3cgroup.Group):
+    label = _(u'Sub-Folders', default="Sub-Folders")
+
+    fields = z3cfield.Fields( ISolgemaFullcalendarProperties ).select(
+        'availableSubFolders',)
+    fields['availableSubFolders'].widgetFactory[INPUT_MODE] = CriteriasOrderedSelectFieldWidget
+
 class ColorsGroup(z3cgroup.Group):
     label = _(u'Colors', default="Colors")
 
     fields = z3cfield.Fields( ISolgemaFullcalendarProperties ).select(
         'queryColors')
-    fields['queryColors'].widgetFactory[INPUT_MODE] = ColorDictInputFieldWidget
 
 
 class SolgemaFullcalendarFormBase(extensible.ExtensibleForm, z3cform.EditForm ):
 
-#    fields = z3cfield.Fields( ISolgemaFullcalendarProperties )
-#    fields['target_folder'].widgetFactory[INPUT_MODE] = QuerySourceFieldRadioWidget
-#    fields['availableCriterias'].widgetFactory[INPUT_MODE] = CriteriasOrderedSelectFieldWidget
-#    fields['queryColors'].widgetFactory[INPUT_MODE] = ColorDictInputFieldWidget
-
-    groups = (CalendarGroup, QueryGroup, ColorsGroup)
-#    index = ViewPageTemplateFile('layout.pt', _prefix='')
-
-    @button.buttonAndHandler(PLMF('label_save'), name='apply')
+    @button.buttonAndHandler(plMF('label_save', default=u'Save'), name='apply')
     def handleApply(self, action):
         data, errors = self.extractData()
         if errors:
@@ -106,9 +101,16 @@ class SolgemaFullcalendarFormBase(extensible.ExtensibleForm, z3cform.EditForm ):
             self.status = self.noChangesMessage
         self.request.RESPONSE.redirect( self.context.absolute_url() )
 
-    @button.buttonAndHandler(PLMF('label_cancel'), name='cancel')
+    @button.buttonAndHandler(plMF('label_cancel', default=u'Cancel'),
+                             name='cancel')
     def handleCancel( self, action):
         self.request.RESPONSE.redirect( self.context.absolute_url() )
 
-SolgemaFullcalendarForm = wrap_form(SolgemaFullcalendarFormBase)
+class SolgemaFullcalendarFormBaseTopic(SolgemaFullcalendarFormBase):
+    groups = (CalendarGroup, TopicQueryGroup, ColorsGroup)
+    
+class SolgemaFullcalendarFormBaseFolder(SolgemaFullcalendarFormBase):
+    groups = (CalendarGroup, FolderQueryGroup, ColorsGroup)
 
+SolgemaFullcalendarFormTopic = wrap_form(SolgemaFullcalendarFormBaseTopic)
+SolgemaFullcalendarFormFolder = wrap_form(SolgemaFullcalendarFormBaseFolder)
